package javax.naming.ldap;

import javax.naming.Context;
import javax.naming.NoInitialContextException;
import javax.naming.NotContextException;
import java.util.Hashtable;
import javax.naming.NamingException;
import javax.naming.directory.InitialDirContext;

public class InitialLdapContext extends InitialDirContext implements LdapContext
{
    private static final String BIND_CONTROLS_PROPERTY = "java.naming.ldap.control.connect";
    
    public InitialLdapContext() throws NamingException {
        super(null);
    }
    
    public InitialLdapContext(Hashtable<?, ?> hashtable, Control[] array) throws NamingException {
        super(true);
        Hashtable<String, Object> environment = (hashtable == null) ? new Hashtable(11) : ((Hashtable)hashtable.clone());
        if (array != null) {
            Control[] value = new Control[array.length];
            System.arraycopy(array, 0, value, 0, array.length);
            environment.put("java.naming.ldap.control.connect", value);
        }
        environment.put("java.naming.ldap.version", "3");
        this.init(environment);
    }
    
    private LdapContext getDefaultLdapInitCtx() throws NamingException {
        Context defaultInitCtx = this.getDefaultInitCtx();
        if (!(defaultInitCtx instanceof LdapContext)) {
            if (defaultInitCtx == null) {
                throw new NoInitialContextException();
            }
            throw new NotContextException("Not an instance of LdapContext");
        }
        else {
            return (LdapContext)defaultInitCtx;
        }
    }
    
    @Override
    public ExtendedResponse extendedOperation(ExtendedRequest extendedRequest) throws NamingException {
        return this.getDefaultLdapInitCtx().extendedOperation(extendedRequest);
    }
    
    @Override
    public LdapContext newInstance(Control[] array) throws NamingException {
        return this.getDefaultLdapInitCtx().newInstance(array);
    }
    
    @Override
    public void reconnect(Control[] array) throws NamingException {
        this.getDefaultLdapInitCtx().reconnect(array);
    }
    
    @Override
    public Control[] getConnectControls() throws NamingException {
        return this.getDefaultLdapInitCtx().getConnectControls();
    }
    
    @Override
    public void setRequestControls(Control[] requestControls) throws NamingException {
        this.getDefaultLdapInitCtx().setRequestControls(requestControls);
    }
    
    @Override
    public Control[] getRequestControls() throws NamingException {
        return this.getDefaultLdapInitCtx().getRequestControls();
    }
    
    @Override
    public Control[] getResponseControls() throws NamingException {
        return this.getDefaultLdapInitCtx().getResponseControls();
    }
}
